Shared wire protocol types for the ap-relay WebSocket server.
This crate contains the protocol types used by both the relay server and relay client, with zero TLS dependencies.
Re-exports
pub use auth::Challenge;pub use auth::ChallengeResponse;pub use auth::Identity;pub use auth::IdentityFingerprint;pub use auth::IdentityKeyPair;pub use auth::SignatureAlgorithm;pub use error::RelayError;pub use messages::Messages;pub use rendezvous::RendezvousCode;
Modules
- auth
- Authentication module for the ap-relay crate. Authentication works by creating a cryptographic identity - a signature key-pair. The identity is the public key. It is proven to the relay, by signing a challenge provided by the relay using the signature key.
- error
- Error types for relay operations.
- messages
- Protocol message types for client-relay communication.
- rendezvous
- Rendezvous codes for temporary peer discovery.