Error types for relay operations.
This module defines all error conditions that can occur during relay client and server operations.
Enums
- Relay
Error - Errors that can occur during relay client or server operations.
Error types for relay operations.
This module defines all error conditions that can occur during relay client and server operations.